/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package advanced;

import java.io.IOException;

import jgromacs.analysis.Dynamics;
import jgromacs.data.Structure;
import jgromacs.data.Trajectory;
import jgromacs.io.IOData;

/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to check the sampling in a simulation
 *  The code calculates the root mean square inner product (RMSIP) and
 *  the covariance matrix overlap between two halves of the same trajectory.
 *  
 */
public class CheckSampling {

	public static void main(String[] args) {
				
		Structure structure;
		Trajectory trajectory;
		
		try {
			// Reading structure and trajectory from file
			structure = IOData.readStructureFromGRO("dataset//example_calpha.gro");
			trajectory = IOData.readDumpedTrajectory(structure,"dataset//example_calpha.dxtc");
			int numOfFrames = trajectory.getNumberOfFrames();
			
			// Extracting the first and the second half of the trajectory
			Trajectory firstHalf = trajectory.getSubTrajectory(0, numOfFrames/2);
			Trajectory secondHalf = trajectory.getSubTrajectory(numOfFrames/2+1, numOfFrames-1);
			
			// Calculating the RMSIP between the two halves
			double RMSIP = Dynamics.getRootMeanSquareInnerProduct(firstHalf, secondHalf, 10, 10);
			
			// Calculating the covariance matrix overlap between the two halves
			double overlap = Dynamics.getCovarianceMatrixOverlap(firstHalf, secondHalf);
			
		} catch (IOException e) {
			e.printStackTrace();
		}
			
	}
	
}