/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package advanced;

import java.io.IOException;

import jgromacs.analysis.Dynamics;
import jgromacs.data.Alignment;
import jgromacs.data.IndexSet;
import jgromacs.data.Structure;
import jgromacs.data.Trajectory;
import jgromacs.io.IOData;

/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to compare the dynamics of conserved residues
 *  The code extracts the match columns from a pairwise sequence
 *  alignment and calculates the Root Mean Square Inner Product (RMSIP)
 *  between the two sets of conserved residues.  
 * 
 */
public class ConservedResidues {

	public static void main(String[] args) {

		Structure structure1;
		Trajectory trajectory1;
		Structure structure2;
		Trajectory trajectory2;
		Alignment alignment;
		
		try {
		// Reading first structure and trajectory from file	
		structure1 = IOData.readStructureFromGRO("dataset//example_calpha.gro");
		trajectory1 = IOData.readDumpedTrajectory(structure1,"dataset//example_calpha.dxtc");
	
		// Reading second structure and trajectory from file		
		structure2 = IOData.readStructureFromGRO("dataset//example_calpha.gro");
		trajectory2 = IOData.readDumpedTrajectory(structure2,"dataset//example_calpha.dxtc");
	
		// Reading pairwise alignment from fasta file
		alignment = IOData.readAlignmentFromFASTA("dataset//example_alignment2.fasta");
		
		// Extracting matched residue indices (which are not aligned to gaps)
		IndexSet match1 = alignment.getMatchPositionIndices(0);
		IndexSet match2 = alignment.getMatchPositionIndices(1);
		
		// Extracting the trajectory of matched residues only
		trajectory1 = trajectory1.getSubTrajectory(match1);
		trajectory2 = trajectory1.getSubTrajectory(match2);
		
		// Calculating RMSIP between the two trajectories
		double RMSIP = Dynamics.getRootMeanSquareInnerProduct(trajectory1, trajectory2, 10, 10);
		
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
