/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
package advanced;

import java.io.IOException;

import jgromacs.analysis.Distances;
import jgromacs.data.FrameIndexSet;
import jgromacs.data.Structure;
import jgromacs.data.Trajectory;
import jgromacs.io.IOData;

/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to normalize atomic distances
 *  The code calculates the percentage of frames in which two atoms are more distant from each other than
 *  a Z-score of 1.1 (calculated based on the total distance distribution between the two atoms).
 *  
 */
public class DistanceDistributions {

	public static void main(String[] args) {
		
		Structure structure;
		Trajectory trajectory;
		
		try {
		// Reading first structure and trajectory from file		
		structure = IOData.readStructureFromGRO("dataset//example_protein.gro");
		trajectory = IOData.readDumpedTrajectory(structure,"dataset//example_protein.dxtc");
		
		// Atom indices
		int atomindex1 = 40;
		int atomindex2 = 85;
		
		// Z-score threshold
		double Zmin = 1.1;
		
		// Calculating mean and standard deviation of distance distribution
		double mean = Distances.getMeanDistance(trajectory, atomindex1, atomindex2);
		double sd = Math.sqrt(Distances.getVarianceOfDistance(trajectory, atomindex1, atomindex2));
				
		// Finding frames where the two atoms are more distant than mean+2*sd (Z-score of 2)
		FrameIndexSet framelist = Distances.getFramesWhereAtomsAreDistant(trajectory, atomindex1, atomindex2, mean+Zmin*sd);
		
		// Percentage of frames where the atomic distance is more than Z-score of 2
		double percentage = 100*framelist.getNumberOfFrames()/trajectory.getNumberOfFrames(); 
		
		} catch (IOException e) {
			e.printStackTrace();
		}
		
	}
	
}
