/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


package advanced;

import java.io.IOException;
import java.util.ArrayList;
import jgromacs.analysis.Distances;
import jgromacs.data.IndexSet;
import jgromacs.data.Structure;
import jgromacs.data.Trajectory;
import jgromacs.io.IOData;

/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to find water molecules in the binding pocket
 *  The code extracts the simulation frame where there are most water molecules
 *  in contact with binding pocket residues
 * 
 */
public class WaterInBindingPocket {

	public static void main(String[] args) {
		
		Structure structure;
		Trajectory trajectory;
		IndexSet bindingPocket;
			
		try {
		// Reading structure and trajectory from file		
		structure = IOData.readStructureFromGRO("dataset//example_full.gro");
		trajectory = IOData.readDumpedTrajectory(structure,"dataset//example_full.dxtc");
	
		bindingPocket = IOData.readIndexSetListFromNDX("dataset//example.ndx").fuseIntoOneIndexSet(); // Reading binding pocket indices from file
		IndexSet waters = structure.getWaterIndexSet();
		
		int max = 0;
		int bestFrameIndex = 0;
		for (int i = 0; i < trajectory.getNumberOfFrames(); i++) {
			Structure frame = trajectory.getFrameAsStructure(i);
			IndexSet closeWaterAtoms = Distances.getAtomIndicesInRadius(frame, waters, bindingPocket, 0.4); // Cutoff = 0.4 nm
			ArrayList<Integer> closeWaterMolecules = structure.mapAtomIndicesToResidueIndices(closeWaterAtoms);
			if (closeWaterMolecules.size()>max){
				max = closeWaterMolecules.size();
				bestFrameIndex = i;
			}
		}
		
		System.out.println("Frame index: "+bestFrameIndex);
		System.out.println("Number of water molecules in the binding pocket: "+max);
		
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
}
