/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package advanced;

import java.io.IOException;
import java.util.ArrayList;

import jgromacs.analysis.Superposition;
import jgromacs.data.IndexSet;
import jgromacs.data.Structure;
import jgromacs.io.IOData;

/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to calculate the weighted superposition of two structures
 *  The code performs weighted superposition of the main chain atoms of two structures
 *  where double weight is assigned to CA atoms than to N, C and O atoms.
 *  
 */
public class WeightedSuperposition {

	public static void main(String[] args) {
		
		Structure structutre1;
		Structure structutre2;
		
		try {
		// Reading structures from files
		structutre1 = IOData.readStructureFromGRO("dataset//example_protein.gro");
		structutre2 = IOData.readStructureFromGRO("dataset//example_protein.gro");
		
		// Extracting main chain atoms
		IndexSet mainChainIndices = structutre1.getMainChainIndexSet();
		Structure structutre1_mainchain = structutre1.getSubStructure(mainChainIndices);
		Structure structutre2_mainchain = structutre2.getSubStructure(mainChainIndices);
		
		// Creating weight vector
		ArrayList<Double> weights = new ArrayList();
		for (int i = 0; i < mainChainIndices.getNumberOfIndices()/4; i++) {
			weights.add(1.0); // N
			weights.add(2.0); // CA
			weights.add(1.0); // C
			weights.add(1.0); // O
		}
		
		// Weighted superposition of the two structures
		Structure superposed = Superposition.weightedSuperposeTo(structutre1_mainchain, structutre2_mainchain, weights);
		
		} catch (IOException e) {
			e.printStackTrace();
		}
		
	}
	
}
