/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


package analysis;

import java.io.IOException;

import jama.Matrix;
import jgromacs.analysis.Distances;
import jgromacs.data.PointList;
import jgromacs.data.Structure;
import jgromacs.data.Trajectory;
import jgromacs.io.IOData;
/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to calculate contact matrices
 * 
 */
public class ContactMatrices {

	
	public static void main(String[] args) {
		
		Structure structure;
		Trajectory trajectory;
		
		try {
			structure = IOData.readStructureFromGRO("dataset//example_protein.gro");
			trajectory = IOData.readDumpedTrajectory(structure,"dataset//example_protein.dxtc");
		
		// Calculating the contact matrix of a point set using a given distance cutoff
		PointList frame = trajectory.getFrameAsPointList(10);
		Matrix contact1 = Distances.getContactMatrix(frame, 0.6);
		
		// Calculating the contact matrix of a structure using a given distance cutoff
		// Inter-residue distance is defined by the distance between the two alpha-carbon atoms:
		Matrix contact2 = Distances.getContactMatrix(structure, Distances.ALPHACARBON, 0.6);
		// Inter-residue distance is defined by the distance between the closest atoms:	
		Matrix contact3 = Distances.getContactMatrix(structure, Distances.CLOSEST, 0.6);
		// Inter-residue distance is defined by the distance between the closest heavy atoms:
		Matrix contact4 = Distances.getContactMatrix(structure, Distances.CLOSESTHEAVY, 0.6);
		
		// Calculating the contact matrix based on the mean residue distance matrix
		Matrix contact5 = Distances.getContactOfMeanMatrix(trajectory, Distances.ALPHACARBON, 0.6);
		
		// Calculating the contact matrix where two residues are said to be in contact if they are in contact 
		// in at least a given percentage of frames in the trajectory
		Matrix contact6 = Distances.getFrequencyContactMatrix(trajectory, Distances.ALPHACARBON, 0.6, 0.75);
		
		} catch (IOException e) {
			
			e.printStackTrace();
		}
		
	}
	
}
