/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package analysis;

import java.io.IOException;

import jama.Matrix;
import jgromacs.analysis.Distances;
import jgromacs.data.IndexSet;
import jgromacs.data.PointList;
import jgromacs.data.Structure;
import jgromacs.data.Trajectory;
import jgromacs.io.IOData;
/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to calculate distance matrices
 * 
 */
public class DistanceMatrices {
	
	public static void main(String[] args) {
		
		Structure structure;
		Trajectory trajectory;
		
		try {
		// Reading structure and trajectory from files
		structure = IOData.readStructureFromGRO("dataset//example_protein.gro");
		trajectory = IOData.readDumpedTrajectory(structure,"dataset//example_protein.dxtc");
		
		// Calculating the distance matrix of a point list
		PointList frame = trajectory.getFrameAsPointList(10);
		Matrix distm = Distances.getDistanceMatrix(frame);
		
		// Calculating the distance matrix of a complete structure (all atoms)
		Matrix distm2 = Distances.getAtomicDistanceMatrix(structure);
		
		// Calculating the distance matrix of a set of atoms
		IndexSet indices = structure.getBackboneIndexSet();
		Matrix distm3 = Distances.getAtomicDistanceMatrix(structure, indices);
		
		// Calculating the distance matrix between two sets of atoms
		IndexSet indices1 = structure.getBackboneIndexSet();
		IndexSet indices2 = structure.getSideChainIndexSet();
		Matrix distm4 = Distances.getAtomicDistanceMatrix(structure, indices1, indices2);
		
		// Calculating the distance matrix of all residues in the structure
		// Inter-residue distance is defined by the distance between the two alpha-carbon atoms:
		Matrix distm5 = Distances.getResidueDistanceMatrix(structure, Distances.ALPHACARBON); 
		// Inter-residue distance is defined by the distance between the closest atoms:
		Matrix distm6 = Distances.getResidueDistanceMatrix(structure, Distances.CLOSEST); 
		// Inter-residue distance is defined by the distance between the closest heavy atoms:
		Matrix distm7 = Distances.getResidueDistanceMatrix(structure, Distances.CLOSESTHEAVY); 
		
		// Calculating mean distance matrices
		Matrix distm8 = Distances.getMeanAtomicDistanceMatrix(trajectory); // Mean atomic distance matrix of all atoms
		Matrix distm9 = Distances.getMeanAtomicDistanceMatrix(trajectory, indices); // Mean atomic distance matrix of a set of atoms
		Matrix distm10 = Distances.getMeanResidueDistanceMatrix(trajectory, Distances.ALPHACARBON); // Mean residue distance matrix (between alpha-carbon atoms)
	
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
}
