/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package analysis;

import java.io.IOException;

import jgromacs.analysis.Distances;
import jgromacs.data.Atom;
import jgromacs.data.IndexSet;
import jgromacs.data.Point3D;
import jgromacs.data.Structure;
import jgromacs.data.Trajectory;
import jgromacs.io.IOData;


/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to do miscellaneous things about distances
 * 
 */
public class DistanceMisc {
	
	public static void main(String[] args) {
		
		Structure structure;
		Trajectory trajectory;
		
		try {
		// Reading structure and trajectory from files
		structure = IOData.readStructureFromGRO("dataset//example_protein.gro");
		trajectory = IOData.readDumpedTrajectory(structure,"dataset//example_protein.dxtc");
		
		// Extracting index group of atoms that are closer to a reference point than a distance cutoff
		Point3D referencePoint = new Point3D(2.4,3.1,1);
		IndexSet indices1 = Distances.getAtomIndicesInRadius(structure, referencePoint, 0.8);
		System.out.println(indices1);
		
		// Extracting index group of atoms that are closer to a reference atom than a distance cutoff
		Atom referenceAtom = structure.getAtomByIndex(127);
		IndexSet indices2 = Distances.getAtomIndicesInRadius(structure, referenceAtom, 0.65);
		System.out.println();
		System.out.println(indices2);
		
		// Extracting index group of atoms that are closer to a reference set of atoms than a distance cutoff
		IndexSet referenceIndices = new IndexSet();
		referenceIndices.addIndex(2);
		referenceIndices.addIndex(3);
		referenceIndices.addIndex(5);
		referenceIndices.addIndex(7);
		referenceIndices.addIndex(11);
		IndexSet indices3 = Distances.getAtomIndicesInRadius(structure, referenceIndices, 0.7);
		System.out.println();
		System.out.println(indices3);
		
		// Calculating the distance between a single atom and a reference set of atoms
		double dist = Distances.getDistanceOfAtomToAtomSet(structure, 34, referenceIndices);
		System.out.println();
		System.out.println(dist);
		
		// Calculating the distance between two sets of atoms
		IndexSet set1 = new IndexSet();
		set1.addIndex(5);
		set1.addIndex(8);
		set1.addIndex(23);
		IndexSet set2 = new IndexSet();
		set2.addIndex(73);
		set2.addIndex(211);
		double dist2 = Distances.getDistanceOfTwoAtomSets(structure, set1, set2);
		System.out.println();
		System.out.println(dist2);
		
		// Finding the atom in a given atom set that is closest to a reference atom set
		IndexSet atomset = structure.getAlphaCarbonIndexSet();
		Atom closestAtom = Distances.findClosestAtom(structure, atomset, referenceIndices);
		System.out.println();
		System.out.println(closestAtom);
		
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
}
