/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package analysis;

import java.io.IOException;
import java.util.ArrayList;

import jgromacs.analysis.Distances;
import jgromacs.analysis.Dynamics;
import jgromacs.data.IndexSet;
import jgromacs.data.Point3D;
import jgromacs.data.Structure;
import jgromacs.data.Trajectory;
import jgromacs.io.IOData;

/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to extract distance time series data 
 * 
 */
public class DistanceTimeSeries {

	
	public static void main(String[] args) {
		
		Structure structure;
		Trajectory trajectory;
		
		try {
		// Reading structure and trajectory from files	
		structure = IOData.readStructureFromGRO("dataset//example_protein.gro");
		trajectory = IOData.readDumpedTrajectory(structure,"dataset//example_protein.dxtc");
		
		// Extracting the trajectory of a single atom in the course of the simulation
		ArrayList<Point3D> atomicTrajectory = Dynamics.getTrajectoryOfAtom(trajectory, 88);
		
		// Extracting the time series of distance between two atoms in a trajectory
		ArrayList<Double> timeseries = Distances.getDistanceTimeSeries(trajectory, 10, 100);
		
		// Getting summary statistics immediately
		double mean = Distances.getMeanDistance(trajectory, 10, 100); // mean distance
		double variance = Distances.getVarianceOfDistance(trajectory, 10, 100); // variance of distance
		double max = Distances.getMaximalDistance(trajectory, 10, 100); // maximum of distance
		double min = Distances.getMinimalDistance(trajectory, 10, 100); // minimum of distance
		double range = Distances.getDistanceRange(trajectory, 10, 100); // distance range (max-min)
		
		// Extracting the time series of distance between a single atom and a reference set of atoms
		IndexSet set = new IndexSet();
		set.addIndex(9);
		set.addIndex(19);
		set.addIndex(29);
		ArrayList<Double> timeseries2 = Distances.getDistanceTimeSeries(trajectory, 10, set);
		
		// Extracting the time series of distance between two sets of atoms
		IndexSet set2 = new IndexSet();
		set2.addIndex(39);
		set2.addIndex(49);
		set2.addIndex(59);
		ArrayList<Double> timeseries3 = Distances.getDistanceTimeSeries(trajectory, set, set2);
		
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
}
