/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package analysis;

import java.io.IOException;

import jgromacs.analysis.Distances;
import jgromacs.analysis.Similarity;
import jgromacs.data.FrameIndexSet;
import jgromacs.data.Point3D;
import jgromacs.data.PointList;
import jgromacs.data.Structure;
import jgromacs.data.Trajectory;
import jgromacs.io.IOData;
/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to extract simulation frames of interest 
 * 
 */
public class FindFrames {

	
	public static void main(String[] args) {
		
		Structure structure;
		Trajectory trajectory;
		
		try {
		// Reading structure and trajectory from files	
		structure = IOData.readStructureFromGRO("dataset//example_protein.gro");
		trajectory = IOData.readDumpedTrajectory(structure,"dataset//example_protein.dxtc");
		
		// Extracting simulation frame where two atoms are closest to each other
		PointList frame1 = Distances.findFrameWhereClosest(trajectory, 15, 150);
		// Extracting simulation frame where two atoms are most distant from each other
		PointList frame2 = Distances.findFrameWhereMostDistant(trajectory, 15, 150);
		
		// Extracting the list of frames in which a given atom is closer to a reference point than a distance cutoff
		Point3D point = new Point3D(1.6,2.8,4.2);
		FrameIndexSet frames1 = Distances.getFramesWhereAtomIsCloseToPoint(trajectory, 130, point, 0.65);
		// Extracting the list of frames in which a given atom is more distant from a reference point than a distance cutoff
		FrameIndexSet frames2 = Distances.getFramesWhereAtomIsDistantFromPoint(trajectory, 130, point, 0.7);
		
		// Extracting the list of frames in which two atoms are closer to each other than a distance cutoff
		FrameIndexSet frames3 = Distances.getFramesWhereAtomsAreClose(trajectory, 15, 29, 0.6);
		// Extracting the list of frames in which two atoms are more distant from each other than a distance cutoff
		FrameIndexSet frames4 = Distances.getFramesWhereAtomsAreDistant(trajectory, 15, 29, 0.6);
		
		// Extracting the list of frames that are more similar to a reference frame than a similarity cutoff
		PointList reference = trajectory.getFrameAsPointList(13);
		FrameIndexSet frames5 = Similarity.findSimilarFramesRMSD(trajectory, reference, 0.1); // based on the RMSD similarity measure
		FrameIndexSet frames6 = Similarity.findSimilarFramesDRMSD(trajectory, reference, 0.08); // based on the dRMSD similarity measure
		
		System.out.println(frames1);
		System.out.println();
		System.out.println(frames2);
		System.out.println();
		System.out.println(frames3);
		System.out.println();
		System.out.println(frames4);
		System.out.println();
		System.out.println(frames5);
		System.out.println();
		System.out.println(frames6);
		
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
}
