/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package analysis;

import jama.Matrix;

import java.io.IOException;
import java.util.ArrayList;

import jgromacs.analysis.Dynamics;
import jgromacs.data.IndexSet;
import jgromacs.data.PointList;
import jgromacs.data.Structure;
import jgromacs.data.Trajectory;
import jgromacs.io.IOData;

/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to calculate residue fluctuations
 * 
 */
public class Fluctuations {

	public static void main(String[] args) {
		
		Structure structure;
		Trajectory trajectory;
		
		try {
		// Reading structure and trajectory from file	
		structure = IOData.readStructureFromGRO("dataset//example_calpha.gro");
		trajectory = IOData.readDumpedTrajectory(structure,"dataset//example_calpha.dxtc");
		
		// Calculating the root mean square fluctuation (RMSF) profile specifying the reference frame for superposition
		PointList reference1 = trajectory.getFirstFrameAsPointList();
		ArrayList<Double> RMSFprofile1 = Dynamics.getRMSFprofile(trajectory, reference1);
		
		// Calculating the root mean square fluctuation (RMSF) profile by superposing all frames to a reference frame  
		// and calculating the deviations with regards to another reference frame
		PointList reference2 = trajectory.getFirstFrameAsPointList();
		PointList reference3 = trajectory.getFrameAsPointList(15);
		ArrayList<Double> RMSFprofile3 = Dynamics.getRMSFprofile(trajectory, reference2, reference3);	
		
		// Calculating the RMSF profile for only a group of atoms
		Structure reference4 = trajectory.getFrameAsStructure(2);
		IndexSet indices = new IndexSet();
		indices.addIndex(4);
		indices.addIndex(13);
		indices.addIndex(56);
		ArrayList<Double> RMSFprofile5 =  Dynamics.getRMSFprofile(trajectory, indices, reference4, indices);
	
		// Calculating the fluctuation matrix (variances of distances)
		Matrix fluctuationMatrix = Dynamics.getFluctuationMatrix(trajectory);
		// Calculating the fluctuation matrix (variances of distances) for only a group of atoms
		IndexSet group = structure.getHeavyProteinIndexSet();
		Matrix fluctuationMatrix2 = Dynamics.getFluctuationMatrix(trajectory, group);
		
		// Calculating the fluctuation between two subsets (please see the definition in the JavaDoc documentation)
		IndexSet set1 = new IndexSet();
		set1.addIndex(4);
		set1.addIndex(7);
		set1.addIndex(44);
		set1.addIndex(444);
		set1.addIndex(777);
		IndexSet set2 = new IndexSet();
		set2.addIndex(5);
		set2.addIndex(88);
		set2.addIndex(103);
		set2.addIndex(431);
		set2.addIndex(1022);
		double fluct = Dynamics.getFluctuationOfSubsets(trajectory, set1, set2);
		
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
}
