/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package analysis;

import java.io.IOException;
import java.util.ArrayList;

import jama.Matrix;
import jgromacs.analysis.Distances;
import jgromacs.analysis.GNM;
import jgromacs.data.Structure;
import jgromacs.io.IOData;
/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to use Gaussian Network Model (GNM)
 * 
 */
public class GaussianNetworkModel {

	
	public static void main(String[] args) {
		
		Structure structure;
				
		try {
		// Reading structure from file	
		structure = IOData.readStructureFromGRO("dataset//example_protein.gro");
			
		// Creating a new GaussianNetworkModel model
		GNM gnm = new GNM(structure, 0.7, Distances.ALPHACARBON);
		
		// Getting results
		Matrix contactMatrix = gnm.getContactMatrix(); // contact matrix
		Matrix KirchhoffMatrix = gnm.getKirchhoffMatrix(); // Kirchhoff matrix
		Matrix Lambda = gnm.getLambdaMatrix(); // diagonal matrix of eigenvalues
		Matrix U = gnm.getEigenvectorMatrix(); // orthogonal matrix of eigenvectors 
		ArrayList<Double> MSFProfile = gnm.getMSFProfile(); // mean square fluctuation profile 
		
		} catch (IOException e) {
			e.printStackTrace();
		}
		
	}
	
}
