/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package analysis;

import java.io.IOException;
import java.util.ArrayList;

import jgromacs.analysis.Superposition;
import jgromacs.data.PointList;
import jgromacs.data.Structure;
import jgromacs.data.Trajectory;
import jgromacs.io.IOData;
/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to superpose structures
 * 
 */
public class Superposing {

	public static void main(String[] args) {
		
		Structure structure;
		Trajectory trajectory;
		
		try {
		// Reading structure and trajectory from file and selecting alpha-carbon atoms only	
		structure = IOData.readStructureFromGRO("dataset//example_protein.gro");
		trajectory = IOData.readDumpedTrajectory(structure,"dataset//example_protein.dxtc");
		trajectory = trajectory.getSubTrajectory(structure.getAlphaCarbonIndexSet());
		
		// Superposing a point list to a reference point list
		PointList frame = trajectory.getFrameAsPointList(12);
		PointList reference = trajectory.getFrameAsPointList(7);
		PointList superposed = Superposition.superposeTo(frame, reference);
		
		// Superposing structures
		Structure frame2 = trajectory.getFrameAsStructure(3);
		Structure reference2 = trajectory.getFrameAsStructure(18);
		Structure superposed2 = Superposition.superposeTo(frame2, reference2);
		
		// Superposing each frame of a trajectory to a common reference frame
		Trajectory superposed3 = Superposition.superposeTo(trajectory, reference); //  reference frame is given as a point list
		Trajectory superposed4 = Superposition.superposeTo(trajectory, reference2); // reference frame is given as a structure
		
		// Weighted superposition of a point list to a reference point list
		ArrayList<Double> weights = new ArrayList(); // vector of weights
		for (int i = 0; i < frame.getNumberOfPoints(); i++) weights.add(1.0);
		PointList weighted_superposed = Superposition.weightedSuperposeTo(frame, reference, weights);
		
		// Weighted superposition of structures
		Structure weighted_superposed2 = Superposition.weightedSuperposeTo(frame2, reference2, weights);
		
		// Weighted superposition of each frame of a trajectory to a common reference frame
		Trajectory weighted_superposed3 = Superposition.weightedSuperposeTo(trajectory, reference, weights); //  reference frame is given as a point list
		Trajectory weighted_superposed4 = Superposition.weightedSuperposeTo(trajectory, reference2, weights); // reference frame is given as a structure
	
		} catch (IOException e) {
			e.printStackTrace();
		}
		
	}
	
}
