/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package data;

import java.io.IOException;
import java.util.ArrayList;
import java.util.TreeSet;

import jgromacs.data.Atom;
import jgromacs.data.IndexSet;
import jgromacs.data.IndexSetList;
import jgromacs.data.Point3D;
import jgromacs.data.PointList;
import jgromacs.data.Residue;
import jgromacs.data.Sequence;
import jgromacs.data.Structure;
import jgromacs.db.AtomType;
import jgromacs.db.ResidueType;
import jgromacs.io.IOData;
/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to use index sets and index set lists
 * 
 */
public class IndexSets {

	public static void main(String[] args) {
		
		IndexSet set1;
		IndexSetList setlist;
		Structure structure;
	
		try {
		// Reading index sets from from files	
		set1 = IOData.readIndexSetFromNDX("dataset//example.ndx");
		setlist = IOData.readIndexSetListFromNDX("dataset//example.ndx");
		
		// Extracting index sets from index set lists
		IndexSet oneset = setlist.getIndexSet(1);
		
		// Extracting index sets from structures
		structure = IOData.readStructureFromPDB("dataset//example_single.pdb");
		IndexSet set2 = structure.getBackboneIndexSet();
		IndexSet set3 = structure.getIndexSetOfChainID("A");
		IndexSetList setlist2 = structure.getDefaultIndexSetList();
		IndexSet set4 = setlist2.getIndexSet("C-alpha");
		
		// Number of indices
		System.out.println(set1.getNumberOfIndices());
		System.out.println(setlist2.getNumberOfAtomsInIndexSet("C-alpha"));
		
		// Number of index sets
		System.out.println(setlist.getNumberOfIndexSets());
		
		// Name of an index set 
		System.out.println(set1.getName());
		set2.setName("setX");
	
		// String representations
		System.out.println();
		System.out.println(set3);
		System.out.println();
		System.out.println(setlist);
		// Summary information
		System.out.println();
		System.out.println(set3.toStringInfo());
		System.out.println();
		System.out.println(setlist.toStringInfo());
		
		// Set operations
		IndexSet set5 = set1.intersect(set2); // Intersection
		IndexSet set6 = set1.union(set2); // Union
		IndexSet set7 = set1.subtract(set2); // subtraction
		IndexSet set8 = setlist.fuseIntoOneIndexSet(); // Fusion of all groups into a single group
		
		// Adding, setting and removing index sets
		setlist.addIndexSet(new IndexSet());
		setlist.removeIndexSet(2);
		setlist.setIndexSet(1, new IndexSet());
		
		// Extracting atomic indices as an ArrayList or TreeSet object
		ArrayList list = set1.getAsArrayList();
		TreeSet treeset = set2.getAsTreeSet();
		
		// Cloning index sets and index set lists
		IndexSet sclone = (IndexSet)set3.clone();
		IndexSetList slclone = (IndexSetList)setlist2.clone();
		
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
}
