/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package data;

import jama.Matrix;

import java.awt.Point;
import java.io.IOException;
import java.util.ArrayList;

import jgromacs.data.Point3D;
import jgromacs.data.PointList;
import jgromacs.data.Structure;
import jgromacs.io.IOData;
/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to use point lists and points
 * 
 */
public class PointLists {

	
	public static void main(String[] args) {
	
		Structure structure;
		
		try {
		// Reading structure from from file
		structure = IOData.readStructureFromGRO("dataset//example_protein.gro");
		
		// Extracting the points of atomic coordinates
		PointList points = structure.getAllAtomCoordinates();
		
		// String representation
		System.out.println(points);
		// Summary information
		System.out.println(points.toStringInfo());
		
		// Number of points
		System.out.println(points.getNumberOfPoints());
		
		// Adding, setting and removing points
		points.addPoint(new Point3D(1,1,1));
		points.setPoint(9, new Point3D(1,2,3));
		points.removePoint(19);
		
		// Extracting points as an ArrayList object
		ArrayList<Point3D> pointsarray = points.getPointsAsArrayList();
		// Setting points from an ArrayList object
		points.setPointFromArrayList(pointsarray);
		
		// Extracting coordinates as a 3xN matrix
		Matrix coordinates = points.getAsMatrix();
		// Loading coordinates from a 3xN matrix
		points.loadFromMatrix(coordinates);
		
		// Calculating the centroid of points
		Point3D centroid = points.getCentroid();
		
		// Translating points
		Point3D vector = new Point3D(1,1,1);
		points.translate(vector);
		
		// Rotating points
		Matrix rotationMatrix = new Matrix(3,3,0);
		points.rotate(rotationMatrix);
		
		// Dealing with points
		Point3D point1 = points.getPoint(22);
		Point3D point2 = structure.getAtom(9).getCoordinates();
		double distance = point1.distance(point2); // distance between points
		double x = point1.getX(); // getting x-coordinate
		point1.setZ(11.1); // setting z-coordinate
		
		// Using points as vectors
		double length = point1.length(); // Length of vector
		Point3D point3 = point1.plus(point2); // addition
		Point3D point4 = point1.minus(point2); // subtraction
		Point3D point5 = point1.multiplyByScalar(2); // multiplication by scalar
		double innerproduct = point1.innerProduct(point2); // inner product
		Point3D point6 = point1.crossProduct(point2); // cross product
		Matrix I = Matrix.identity(3, 3); 
		Point3D point7 = point1.transformByMatrix(I); // Transforming by matrix
		
		// Cloning points and point lists
		Point3D cpoint = (Point3D)point1.clone();
		PointList cpoints = (PointList)points.clone();
		
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
}
