/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package input;

import java.io.IOException;

import jgromacs.data.Structure;
import jgromacs.io.IOData;

/**
 * 
 *  Example code for the JGromacs v1.0. package
 *  Topic: How to read structures from PDB or GRO file
 * 
 */

public class ReadStructures {
	
	public static void main(String[] args) {
		
		try {
	
		// Reading a structure from a PDB file
		Structure structure = IOData.readStructureFromPDB("dataset//example_single.pdb");
		System.out.println(structure.getNumberOfResidues()); // Writing out the number of residues
		
		// Reading an ensemble of structures from a series of PDB files
		Structure[] structures = IOData.readStructuresFromPDBsInDirectory("dataset//");
		System.out.println(structures.length); // Writing out the number of structures
		
		// Reading a given model from a PDB file
		Structure structure2 = IOData.readStructureFromPDB("dataset//example_ensemble.pdb", 4);
		System.out.println(structure2.getNumberOfAtoms()); // Writing out the number of atoms
		// Reading an ensemble of structures from a single PDB file
		Structure[] structures2 = IOData.readStructuresFromPDB("dataset//example_ensemble.pdb");
		System.out.println(structures2.length); // Writing out the number of models
		
		// Reading a structure from a GRO file
		Structure structure3 = IOData.readStructureFromGRO("dataset//example_calpha.gro");
		System.out.println();
		System.out.println(structure3); // Writing out the String representation of structure3
		
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		
	}

}
